@@ -812,6 +812,24 @@ mod tests {
         exec.shutdown().expect("Pool didn't shut down!");
     }
 
+    #[test]
+    fn test_custom_small() {
+        let exec = ThreadPool::new(4, parker::small());
+        crate::tests::test_custom(exec, LABEL);
+    }
+
+    #[test]
+    fn test_custom_large() {
+        let exec = ThreadPool::new(36, parker::large());
+        crate::tests::test_custom(exec, LABEL);
+    }
+
+    #[test]
+    fn test_custom_dyn() {
+        let exec = ThreadPool::new(72, parker::dynamic());
+        crate::tests::test_custom(exec, LABEL);
+    }
+
     #[test]
     fn test_defaults() {
         crate::tests::test_defaults::<ThreadPool<DynParker>>(LABEL);
