@@ -573,10 +573,12 @@ impl ThreadData for DynamicThreadData {
     }
 
     fn prepare_park(&self, _thread_id: usize) -> () {
+    	//println!("Preparing to park {}", _thread_id);
         self.sleep_count.fetch_add(1usize, Ordering::SeqCst);
     }
 
     fn abort_park(&self, _thread_id: usize) -> () {
+    	//println!("Aborting park {}", _thread_id);
         self.sleep_count.fetch_sub(1usize, Ordering::SeqCst);
     }
 
@@ -590,22 +592,28 @@ impl ThreadData for DynamicThreadData {
                     unreachable!("Inconsistent sleeping map (before park)!");
                 }
             } else {
-                guard.no_sleep -= 1;
+            	//println!("Aborting park due to no_sleep {}", thread_id);
+                guard.no_sleep -= 1; // must be >0 because we hold the lock
                 self.sleep_count.fetch_sub(1usize, Ordering::SeqCst);
                 return ParkResult::Abort;
             }
         } else {
             return ParkResult::Retry; // if the lock can't be acquired, don't park, because maybe a client is trying to wake up things anyway
         }
+        //println!("Parking {}", thread_id);
         thread::park();
+        //println!("Not parking {} anymore, but waiting for lock.", thread_id);
         if let Ok(mut guard) = self.data.lock() {
+            //println!("Got lock.");
             self.sleep_count.fetch_sub(1usize, Ordering::SeqCst);
             guard
                 .sleeping
                 .remove(&thread_id)
                 .expect("Inconsistent sleeping map (after park)!");
+            //println!("Woke {}", thread_id);
             return ParkResult::Woken;
         } else {
+            //eprintln!("Fuck, I'll panic!");
             panic!("Mutex is poisoned!");
         }
     }
@@ -618,11 +626,14 @@ impl ThreadData for DynamicThreadData {
     fn unpark_one(&self) -> () {
         if let Ok(mut guard) = self.data.lock() {
             if self.sleep_count.load(Ordering::SeqCst) > 0usize {
-                while let Some(state) = guard.sleeping.values_mut().next() {
+                for state in guard.sleeping.values_mut() {
+                    //println!("Hanging on to the lock (one) {}...", count);
                     match state {
                         ParkState::Asleep(t) => {
+                        	//println!("Unparking {:?}", t);
                             t.unpark();
                             *state = ParkState::Waking;
+                            return;
                         }
                         ParkState::Waking => (), // skip
                         ParkState::Awake | ParkState::NoSleep => {
@@ -630,8 +641,9 @@ impl ThreadData for DynamicThreadData {
                         }
                     }
                 }
+                //println!("Preventing a thread from going to sleep.");
                 // no one to wake -> prevent next thread from going to sleep
-                guard.no_sleep += 1;
+                guard.no_sleep = guard.no_sleep.saturating_add(1); // don't overflow this during shutdown
             } // no one is sleeping, nothing to do
         } else {
             panic!("Mutex is poisoned!");
@@ -642,6 +654,7 @@ impl ThreadData for DynamicThreadData {
         if let Ok(mut guard) = self.data.lock() {
             if self.sleep_count.load(Ordering::SeqCst) > 0usize {
                 for state in guard.sleeping.values_mut() {
+                    //println!("Hanging on to the lock (all)...");
                     match state {
                         ParkState::Asleep(t) => {
                             t.unpark();
